% Pole Placement Design for Magnetic Suspension
clear all;

% =============================================
% Pole Placement Design for Magnetic Suspension
% =============================================
% Model Parameters
Km = 1E-4;
d = 0.04;
m = 0.1;
g = 10;
i0 = sqrt(m*g/Km)*d/2;
Ki = 2*Km*i0/(d/2)^2;
Kx = 2*Km*i0^2/(d/2)^3;

% ======================================
% Extended Pole Placement without filter
% ======================================
% Inner Loop
l0 = 0;
l2 = 1000;
l1 = 40000;
l1p = l2;
l0p = l1;
p2 = (600 + l1p)*100;
p1 = (4000 + l0p)*100;
p0 = 1000000;
% Filter
R0 = 1;
f0 = 1;
f1 = 0; 
f2 = 0;
% reference tracking
ref = d/4;
d_load = 0;
% simulation
options = simset('Solver','ode23s');
sim('ECE441_Ex8_solution',[0,20],options);
figure(1);
plot(t_magnet,y,t_magnet,d/4);
legend('reference step $x = d/4$','reference value d/4')
grid
xlabel('time [sec]')
ylabel('potition [m/s]')

figure(2);
plot(t_magnet,u);
legend('control output u')
grid
xlabel('time [sec]')
ylabel('potition [m/s]')
% disturbance rejection
ref = 0;
d_load = 0.05;
sim('ECE441_Ex8_solution',[0,20],options);
figure(3);
plot(t_magnet,y);
legend('disturbance step $F_\mathrm{L} = 0.5 N$')
grid
xlabel('time [sec]')
ylabel('position [m/s]')


% ======================================
% Extended Pole Placement
% ======================================
% Inner Loop
l0 = 0;
l2 = 1000;
l1 = 40000;
l1p = l2;
l0p = l1;
p2 = (600 + l1p)*100;
p1 = (4000 + l0p)*100;
p0 = 1000000;
% Filter
R0 = 1;
f0 = 1;
f1 = 4.4; 
f2 = 0.16;
% reference tracking
ref = d/4;
d_load = 0;
% simulation
options = simset('Solver','ode23s');
sim('ECE441_Ex8_solution',[0,20],options);
figure(4);
hold on;
plot(t_magnet,y,t_magnet,d/4);
legend('reference step $x = d/4$','reference value d/4')
grid;
xlabel('time [sec]')
ylabel('potition [m/s]')

figure(5);
plot(t_magnet,u);
legend('control output u')
grid
xlabel('time [sec]')
ylabel('potition [m/s]')
% disturbance rejection
ref = 0;
d_load = 0.05;
sim('ECE441_Ex8_solution',[0,20],options);
figure(6);
plot(t_magnet,y);
legend('disturbance step $F_\mathrm{L} = 0.5 N$')
grid
xlabel('time [sec]')
ylabel('position [m/s]')

% ==========================0
% Problem 17
u_ref = 1;
sim('ECE441_Ex8_solution_P17',[0,.1],options);
figure(7);
plot(time,y);
legend('sinusoidal reference signal')
grid
xlabel('time [sec]')
ylabel('output')

u_ref = 0;
sim('ECE441_Ex8_solution_P17',[0,.1],options);
figure(8);
plot(time,y);
legend('sinusoidal disturbance signal')
grid
xlabel('time [sec]')
ylabel('output')


